# anchor: body: v2

|   |   |   |
| --- | --- | --- |
| [![image](https://github.com/kamangir/assets2/blob/main/anchor/20251205_175910.jpg?raw=true)](https://github.com/kamangir/assets2/blob/main/anchor/20251205_175910.jpg?raw=true) | [![image](https://github.com/kamangir/assets2/blob/main/anchor/20251205_175916.jpg?raw=true)](https://github.com/kamangir/assets2/blob/main/anchor/20251205_175916.jpg?raw=true) | [![image](https://github.com/kamangir/assets2/blob/main/anchor/20251205_175920.jpg?raw=true)](https://github.com/kamangir/assets2/blob/main/anchor/20251205_175920.jpg?raw=true) |
| [![image](https://github.com/kamangir/assets2/blob/main/anchor/20251205_175932.jpg?raw=true)](https://github.com/kamangir/assets2/blob/main/anchor/20251205_175932.jpg?raw=true) | [![image](https://github.com/kamangir/assets2/blob/main/anchor/20251205_175936.jpg?raw=true)](https://github.com/kamangir/assets2/blob/main/anchor/20251205_175936.jpg?raw=true) | [![image](https://github.com/kamangir/assets2/blob/main/anchor/20251205_175941.jpg?raw=true)](https://github.com/kamangir/assets2/blob/main/anchor/20251205_175941.jpg?raw=true) |
| [![image](https://github.com/kamangir/assets2/blob/main/anchor/20251205_175953.jpg?raw=true)](https://github.com/kamangir/assets2/blob/main/anchor/20251205_175953.jpg?raw=true) |  |  |
